@@ -1,18 +1,15 @@
-# @(#)$Ident: Cloud.pm 2013-05-16 14:22 pjf ;
-
 package HTML::FormWidgets::Cloud;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(data height width) );
+__PACKAGE__->mk_accessors( qw( data height width ) );
 
 sub init {
    my ($self, $args) = @_;
 
-   $self->class    ( q(cloud) );
+   $self->class    ( 'cloud' );
    $self->container( 0  );
    $self->data     ( [] );
    $self->height   ( 18 );
@@ -27,8 +24,9 @@ sub render_field {
       my $ref    = $item->{value} || {};
       my $id     = $ref->{id   }  || $item->{tag};
       my $style  = $ref->{style};
-      my $attrs  = { class => $self->class.q(_header fade live_grid),
-                     href  => $ref->{href } || 'javascript:Expand_Collapse()',
+      my $href   = $self->uri_for( $ref->{href} );
+      my $attrs  = { class => $self->class.'_header fade live_grid',
+                     href  => $href || 'javascript:Expand_Collapse()',
                      id    => $id };
 
       if ($item->{size}) {
@@ -48,14 +46,14 @@ sub render_field {
       my $text   = $item->{tag}.'('.$item->{count}.')';
       my $anchor = $hacc->a( $attrs, "\n".$text );
 
-      $attrs     = { class => $self->class.q(_header) };
+      $attrs     = { class => $self->class.'_header' };
       $html     .= $hacc->div( $attrs, "\n".$anchor )."\n";
 
       $ref->{href} and next;
 
       $style     = defined $self->width ? 'width: '.$self->width.'px;' : q();
-      $html     .= $hacc->div( { class => $self->class.q(_panel),
-                                 id    => $id.q(Disp),
+      $html     .= $hacc->div( { class => $self->class.'_panel',
+                                 id    => "${id}Disp",
                                  style => $style }, 'Loading...' );
    }
 
