@@ -1,13 +1,10 @@
-# @(#)$Ident: Image.pm 2013-05-16 14:22 pjf ;
-
 package HTML::FormWidgets::Image;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(fhelp subtype) );
+__PACKAGE__->mk_accessors( qw( fhelp subtype ) );
 
 sub init {
    my ($self, $args) = @_;
@@ -21,12 +18,15 @@ sub init {
 sub render_field {
    my ($self, $args) = @_; my $hacc = $self->hacc;
 
-   $args = { alt => $self->fhelp, src => $self->text };
+   my $src = 'http:' eq (substr $self->text, 0, 5)
+           ? $self->text : ($self->options->{assets} // q()).$self->text;
+
+   $args = { alt => $self->fhelp, src => $src };
 
    $self->class and $args->{class} = $self->class;
    $self->id    and $args->{id   } = $self->id;
 
-   $self->subtype eq q(icon) and return $hacc->span( $args );
+   $self->subtype eq 'icon' and return $hacc->span( $args );
 
    return $hacc->img( $args );
 }
