@@ -1,19 +1,18 @@
-# @(#)$Ident: Password.pm 2013-05-16 14:21 pjf ;
-
 package HTML::FormWidgets::Password;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(subtype width) );
+__PACKAGE__->mk_accessors( qw( subtype width ) );
+
+my $NBSP = '&#160;';
 
 sub init {
    my ($self, $args) = @_;
 
-   $self->subtype( q(normal) );
-   $self->width  ( 20        );
+   $self->subtype( 'normal' );
+   $self->width  ( 20       );
    return;
 }
 
@@ -34,14 +33,14 @@ sub render_field {
       $self->add_literal_js( 'inputs', $id2, $options );
    }
 
-   $args->{class} .=  q( ifield).($reveal ? q( reveal) : q());
+   $args->{class} .=  ' ifield'.($reveal ? ' reveal' : q());
    $args->{size }  =  $self->width;
 
    my $html        =  $hacc->password_field( $args );
 
    $subtype        =~ m{ verify }msx or return $html;
-   $html          .=  $hacc->span( { class => q(prompt) },
-                                   $self->loc( q(vPasswordPrompt) ) );
+   $html          .=  $hacc->span( { class => 'prompt' },
+                                   $NBSP.$self->loc( 'and again' ).$NBSP );
    $args->{name}   =~ s{ 1 }{2}mx; $args->{id} =~ s{ 1 }{2}mx;
    $html          .=  $hacc->password_field( $args );
    return $html;
