@@ -1,13 +1,10 @@
-# @(#)$Ident: Rule.pm 2013-05-16 14:21 pjf ;
-
 package HTML::FormWidgets::Rule;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
-use parent qw(HTML::FormWidgets);
+use parent 'HTML::FormWidgets';
 
-__PACKAGE__->mk_accessors( qw(alt config href imgclass) );
+__PACKAGE__->mk_accessors( qw( alt config href imgclass ) );
 
 sub init {
    my ($self, $args) = @_;
